@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Alien::PCRE2;
 
-our $VERSION = '0.004000';
+our $VERSION = '0.005000';
 
 use base qw( Alien::Base );
 
@@ -32,12 +32,6 @@ From a Perl script
 
 This package can be used by other CPAN modules that require PCRE2 or libpcre2.
 
-B<PLEASE NOTE: This distribution will automatically call C<make install> as part of the C<make test> step!>
-
-This is necessary to avoid the following error when testing the C<pcre2grep> command:
-
-S<C<I<error while loading shared libraries: libpcre2-8.so.0: cannot open shared object file: No such file or directory>>>.
-
 =head1 AUTHOR
 
 William N. Braswell, Jr. <wbraswell@cpan.org>
